pub fn begin_graph_write(
backend: Arc<dyn PersistentStorageBackend>,
) -> GraphStoreResult<Box<dyn GraphWriteTransaction>>Expand description
Open a write transaction or a nested savepoint on the exact storage session.
pub fn begin_graph_write(
backend: Arc<dyn PersistentStorageBackend>,
) -> GraphStoreResult<Box<dyn GraphWriteTransaction>>Open a write transaction or a nested savepoint on the exact storage session.