pub struct GraphDelta { /* private fields */ }Expand description
Records add / remove vertex / edge operations (Section 9.3, Paper 2).
Implementations
Sourceimpl GraphDelta
impl GraphDelta
pub fn new() -> Self
pub fn add_vertex(&mut self, vertex: Vertex)
pub fn remove_vertex(&mut self, vertex_id: VertexId)
pub fn add_edge(&mut self, edge: Edge)
pub fn remove_edge(&mut self, edge_id: EdgeId)
pub fn ops(&self) -> &[DeltaOp]
pub fn is_empty(&self) -> bool
pub fn len(&self) -> usize
Sourcepub fn affected_vertex_ids(&self) -> BTreeSet<VertexId>
pub fn affected_vertex_ids(&self) -> BTreeSet<VertexId>
Set of vertex ids touched by any op (vertices added / removed, plus the source / target of added edges). Edge removal does not resurrect a vertex id since the operation only stores the edge id.
Sourcepub fn affected_edge_labels(&self) -> BTreeSet<String>
pub fn affected_edge_labels(&self) -> BTreeSet<String>
Set of edge labels touched by AddEdge ops. Used by the
versioned store to invalidate path indexes that depend on a
label.