pub struct TemporalPatternMatch<'a> {
pub pattern: GraphPattern,
pub graph: &'a str,
pub temporal_filter: TemporalFilter,
pub score: f64,
}Expand description
Temporal-aware pattern matching (Section 10, Paper 2).
Same algorithm as the standard subgraph matcher but every edge
candidate is filtered through a TemporalFilter before it is
admitted into the assignment, so only temporally valid edges
participate in pattern matching.
Fields
pattern: GraphPatterngraph: &'a strtemporal_filter: TemporalFilterscore: f64Implementations
Sourceimpl<'a> TemporalPatternMatch<'a>
impl<'a> TemporalPatternMatch<'a>
pub fn new(pattern: GraphPattern, graph: &'a str) -> Self
pub fn filter(self, filter: TemporalFilter) -> Self
pub fn score(self, score: f64) -> Self
pub fn execute<G: GraphStore>( &self, store: &G, ) -> GraphStoreResult<GraphPostingList>